#
# spec file for package tcsh (Version 6.14.00)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           tcsh
BuildRequires:  xorg-x11-devel
Url:            http://www.tcsh.org/
License:        BSD 3-Clause
Group:          System/Shells
Requires:       gawk textutils
AutoReqProv:    on
Version:        6.14.00
Release:        23.16.29
Summary:        The C SHell
Source:         ftp.astron.com:/pub/tcsh/tcsh-6.14.00.tar.bz2
Source1:        nls-iconv
Patch:          tcsh-6.14.00.dif
Patch1:         tcsh-6.14.00-spelling.dif
Patch2:         tcsh-6.14.00-bsdsignals.dif
Patch3:         tcsh-6.14.00-utf8.dif
Patch4:         tcsh-6.14.00-pipe.dif
Patch5:         tcsh-6.14.00-tabexpand.dif
Patch6:         tcsh-6.14.00-bug-297191.patch
Patch7:         tcsh-6.14.00-noexec.dif
Patch8:         tcsh-6.14.00-sigchld.dif
Patch9:         tcsh-6.14.00-grabpgrp.dif
Patch10:        tcsh-6.12.00-fullpath.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tcsh is an enhanced, but completely compatible, version of the Berkeley
UNIX C shell, csh(1). It is a command language interpreter usable as an
interactive login shell and a shell script command processor. It
includes a command-line editor, programmable word completion, spelling
correction, a history mechanism, job control, and a C-like syntax.



Authors:
--------
    Christos Zoulas <christos@deshaw.com>
    Scott Krotz <krotz@mot.com>

%prep
%setup
%patch1 -p0 -b .spell
%patch2 -p0 -b .bsdsig
%patch3 -p0 -b .utf8
%patch4 -p0 -b .pipe
%patch5 -p0 -b .tabexpand
%patch6 -p0 -b .sigsegv
%patch7 -p0 -b .noexec
%patch8 -p0 -b .sigchld
%patch9 -p0 -b .pgrp
%patch10 -p0 -b .fullpath
%patch
    sh $RPM_SOURCE_DIR/nls-iconv

%build
    CC=gcc
    CFLAGS="$RPM_OPT_FLAGS -pipe"
    export CC CFLAGS
%ifarch %ix86
    CPU=i586
%else
    CPU=${RPM_ARCH}
%endif
    ./configure --build=${CPU}-suse-linux \
	--prefix=/usr			\
	--bindir=/bin			\
	--sysconfdir=/etc		\
	--localstatedir=/var		\
	--sharedstatedir=/usr/share	\
	--infodir=/usr/share/info	\
	--mandir=/usr/share/man		\
	--libexecdir=/usr/%{_lib}/tcsh
    make
    make catalogs

%install
    rm -rf $RPM_BUILD_ROOT
    for nls in et fi fr de el it ja pl ru es uk_UA ; do
	dir=$RPM_BUILD_ROOT/usr/share/locale/${nls}/LC_MESSAGES
	msg=$nls
	mkdir -p -m 0755 $dir
	case "$nls" in
	fi)	msg=finnish	;;
	fr)	msg=french	;;
	de)	msg=german	;;
	el)	msg=greek	;;
	it)	msg=italian	;;
	ru)	msg=russian	;;
	es)	msg=spanish	;;
	uk_UA)	msg=ukrainian	;;
	esac
	install -m 0444 tcsh.${msg}.cat ${dir}/tcsh
    done
    make DESTDIR=$RPM_BUILD_ROOT install
    make DESTDIR=$RPM_BUILD_ROOT install.man
    mkdir -p $RPM_BUILD_ROOT%{_docdir}/tcsh
    install -m 0444 FAQ $RPM_BUILD_ROOT%{_docdir}/tcsh/FAQ.tcsh
    mkdir -p $RPM_BUILD_ROOT/etc/profile.d/
    mkdir -p $RPM_BUILD_ROOT/usr/bin
    install -m 644 SuSE/bindkey.tcsh  $RPM_BUILD_ROOT/etc/profile.d/
    install -m 644 SuSE/complete.tcsh $RPM_BUILD_ROOT/etc/profile.d/
    rm -f $RPM_BUILD_ROOT/bin/csh
    rm -f $RPM_BUILD_ROOT/usr/bin/csh
    rm -f $RPM_BUILD_ROOT/usr/bin/tcsh
    rm -f $RPM_BUILD_ROOT/usr/share/man/man1/csh.*
    ln -sf tcsh           $RPM_BUILD_ROOT/bin/csh
    ln -sf tcsh.1.gz      $RPM_BUILD_ROOT/usr/share/man/man1/csh.1.gz
    ln -sf ../../bin/tcsh $RPM_BUILD_ROOT/usr/bin/csh
    ln -sf ../../bin/tcsh $RPM_BUILD_ROOT/usr/bin/tcsh

%clean
    rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%dir %{_docdir}/tcsh
/bin/csh
/bin/tcsh
%config /etc/profile.d/bindkey.tcsh
%config /etc/profile.d/complete.tcsh
/usr/bin/csh
/usr/bin/tcsh
%doc %{_docdir}/tcsh/FAQ.tcsh
%doc /usr/share/man/man1/csh.1.gz
%doc /usr/share/man/man1/tcsh.1.gz
/usr/share/locale/*/LC_MESSAGES/tcsh

%changelog
* Tue Mar 31 2009 werner@suse.de
- Add and enable patch to avoid endless loop due incorrect tty
  process group (bnc#472866)
* Wed Nov 26 2008 werner@suse.de
- For commands with full execution path bypass correction algorithm
  if the command is found (bnc#444992)
* Thu Apr  3 2008 werner@suse.de
- Do not allow SIGCHLD to interrupt system calls (bnc#369433)
* Mon Mar 10 2008 werner@suse.de
- Fix core dump and error messages in debug mode (bnc#361966)
* Mon Aug 27 2007 werner@suse.de
- Fix a SIGSEGV in multibyte handling (bug #297191)
* Wed Jun 21 2006 werner@suse.de
- Do not overwrite memory by not initialized Char array (#186669)
* Wed Apr 26 2006 werner@suse.de
- Fix typo in compelete macro for the command man
* Tue Apr 25 2006 werner@suse.de
- Add new LS_COLORS variables to avoid error message (bug #168601)
* Mon Apr 10 2006 werner@suse.de
- Tcsh completion: expand also for sections of posix manual pages
  and include section 0 into search scheme (bug #160782)
* Thu Mar 23 2006 werner@suse.de
- Source the users ~/.cshrc and ~/.login in the traditional order,
  nevertheless the system wide /etc/csh.cshrc and /etc/csh.login
  will be sourced in the natual order (bug #160278)
* Mon Feb  6 2006 werner@suse.de
- Make $< operator work even when fed by pipe (bug #147724)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 25 2005 werner@suse.de
- Switch order of sourcing csh.login csh.cshrc, now csh.login
  comes first to provide all exported environment variables.
* Thu Aug 18 2005 werner@suse.de
- Update to tcsh 6.14.00, the wide character version (bug #104108).
* Mon May 23 2005 werner@suse.de
- Make mh handling more smarter
* Fri Apr  1 2005 werner@suse.de
- Gcc4 does not allow function prototype declaration within other
  function prototype declaration even if the internals are static.
* Fri Oct  8 2004 werner@suse.de
- Make fcntl call with O_LARGEFILE portable (bug #46977)
* Thu May 27 2004 ro@suse.de
- fix sigpause call (force use of sysv flavour)
* Fri Apr  2 2004 mls@suse.de
- fix utf-8 expansion, ls-F, prompt handling
* Mon Mar 29 2004 mls@suse.de
- fix utf-8 handling (really fixes #29983, #35486)
* Tue Mar 16 2004 werner@suse.de
- Do not forget the patch for bug #29983 even if not used
- Accept chinese in dspmbyte and map this on euc
* Wed Mar 10 2004 werner@suse.de
- Disable multibyte ix due problems on long lines (bug #35486)
- Simplify mv/cp complete
* Thu Mar  4 2004 werner@suse.de
- Fix mv/cp complete bug (#35339)
* Fri Feb 20 2004 werner@suse.de
- Add simple workaround for multibyte command lines (bug #29983)
* Wed Jan 28 2004 werner@suse.de
- Fix bug #34126: add runtime detection as fallback
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Fri Sep 19 2003 werner@suse.de
- Fix the fix for bug #29956: use a ringbuffer to avoid trouble
  with recursive calls of UTF-8 convertes messges (bug #31335)
* Thu Sep  4 2003 werner@suse.de
- Corruption of cursor position is currently not fixable.
  fix some other bugs.
* Wed Sep  3 2003 mfabian@suse.de
- Bugzilla #29956: convert all message catalogs to UTF-8 and
  convert the strings returned by catgets from UTF-8 into the
  encoding of the current locale.
- move Ukrainian message catalog into uk_UA subdirectory
  instead of ru_UA.koi8u.
* Fri Jul 18 2003 werner@suse.de
- Fix multi byte initialization (bug #27793)
- Enable multi byte unset on LANG change
- Fix signess/unsigness mixtures
* Fri May 23 2003 coolo@suse.de
- use BuildRoot
* Wed May 14 2003 werner@suse.de
- Move pointer adress handling from int to intptr_t
* Thu Apr 17 2003 werner@suse.de
- Fix multibyte initialization
* Mon Feb 17 2003 werner@suse.de
- Fix bug #23681: don't reset full command line if an error occurs
* Mon Nov 11 2002 ro@suse.de
- use x-devel-packages in neededforbuild
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Aug  7 2002 werner@suse.de
- Fix bindkey.tcsh for xterm and add some more keys (bug #15002)
* Tue Jul 30 2002 werner@suse.de
- Update to 6.12.00
- Fix codesets of message cats
* Fri Jul 19 2002 mls@suse.de
- fix bindkey.tcsh to make it work with an unset $TERM variable
* Wed Mar 20 2002 werner@suse.de
- Fix bug # 15143: Unreadable /etc/printcap due paranoid SysAdmins
  should not stop tcsh.
* Wed Dec 12 2001 werner@suse.de
- Revisit some complete expansion (mainly for mv, cp, make, and
  man), sed error scanners should work for all languages.
* Thu Sep  6 2001 werner@suse.de
- Update to 6.11.00 due
  * correct large file support
  * Avoid core-dumping on very long $HOME variable
  * Don't call qsort(3) with 0 items
  * Fix redrawing in the recognize case
  * MAXHOSTNAMELEN needs to be 256 (instead of 255)
  * Big5 multibyte support
  * Fix rmstar not to corrupt memory on off
* Wed May 16 2001 werner@suse.de
- Force large file support
* Wed May  9 2001 cstein@suse.de
- Corrected German spellings in nls/german/set6
* Wed Mar  7 2001 werner@suse.de
- We use xmkmf therefore we need a full X environment at build
* Fri Feb  9 2001 werner@suse.de
- Don't use the authors (endless looping) security temp file
  change but the mkstemp() function.
* Fri Feb  2 2001 mfabian@suse.de
- update to version 6.10.00
  (because the new version has  support for display and editing of
  multibyte characters)
- add patch to enable multibyte character editing
- patch to glob.c removed (included upstream)
- patch to sh.dir.c removed (included upstream)
- patch to tw.color.c removed (incuded upstream)
- last hunk of patch to tw.h removed (included upstream)
- bzip2 sources
* Fri Dec 15 2000 werner@suse.de
- Add missed hash for a comment.
* Wed Nov 22 2000 werner@suse.de
- Make /etc/profile.d/bindkey.tcsh knowing about TERM kvt and gnome
* Fri Nov 17 2000 kukuk@suse.de
- fix neededforbuild: textutil -> textutils
* Thu Nov  2 2000 werner@suse.de
- Use mkstemp for opening tmp files for `<<' redirects
  - Use TMPDIR variable for location of tmp files
  - Set group tag in spec
* Wed May 24 2000 uli@suse.de
- moved docs to %%{_docdir}
* Wed Jan 26 2000 werner@suse.de
- New version 6.09.00
  - /usr/man -> /usr/share/man
  - Fix usage of catopen (MCLoadBySet isn't that what is used
  internally within glibc, set it to MCLoadBySet)
  - Avoid crahs due coloured ls-F
  - Correct setpath NLS message
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jun 28 1999 werner@suse.de
- Source key binding and completion code from
  /etc/csh.cshrc out into /etc/profile.d/bindkey.tcsh and
  /etc/profile.d/complete.tcsh
  - No newgrp builtin because its equivalent to exec newgrp
* Wed Jun 16 1999 ro@suse.de
- create localedirs before make install
* Fri Jun 11 1999 werner@suse.de
- New version
  Fri Mar 12 14:21:46 MET 1999
  - Fix SIGSEGV caused different sizes of FILSIZ and BUFSIZE
  - New version
  - Restore missed MAXNAMLEN
  - Make it alpha compile
* Thu Dec  3 1998 werner@suse.de
- Fix SIGSEGV with SYSMALOC
  * alloc n+1 not n chunks
  * set freed pointer to (ptr_t)NULL
* Wed Sep 16 1998 werner@suse.de
- Stupid error fixed
* Tue Sep 15 1998 werner@suse.de
- Security fix
  - Avoid I/O trouble, use POSIX
* Wed Oct 22 1997 werner@suse.de
- Updatet FAQ.tcsh
  - Better installation: remove old files before linking
* Thu Jan  2 1997 bs@suse.de
  added FAQ.tcsh
* Thu Jan  2 1997 werner@suse.de
- Neue Version 6.07.02 mit einigen Fixes
